// EOAttributeOrdering.h
// Copyright (c) 1994, NeXT Computer, Inc. All rights reserved.

#import <foundation/NSArray.h>
#import <foundation/NSData.h>
#import <foundation/NSDictionary.h>
#import <foundation/NSObject.h>
#import <foundation/NSString.h>

@class EOAttribute;

typedef enum {
    EOAnyOrder, EOAscendingOrder, EODescendingOrder
} EOOrdering;
    // EOOrdering encodes the three possible orders for a set of values.


// EOAttributeOrdering defines the order in which rows/objects are returned
// when fetching.  You usually create EOAttributeOrderings and put them into
// an NSArray for a select operation.  The order within the array determines
// the precedence when sorting.  See any of the methods that use a fetchOrder:
// keyword in the selector for further information.


@interface EOAttributeOrdering:NSObject <NSCopying>
{
    EOAttribute *_attribute;
    EOOrdering _ordering;
}

+ attributeOrderingWithAttribute:(EOAttribute *)attribute 
    ordering:(EOOrdering)ordering;
    // Convenience method to return an autoreleased EOAttributeOrdering.

- initWithAttribute:(EOAttribute *)attribute ordering:(EOOrdering)ordering;
    // Initializes the receiver with attribute and ordering. Returns self.

- (EOAttribute *)attribute;
    // Returns the attribute that the ordering is defined for.

- (EOOrdering)ordering;
    // Returns the ordering defined for the attribute.

@end
